FAQ — Django FileBrowser 3.11.2 documentation

# FAQ

## Why should I use the FileBrowser?

If you need your editors or customers to manage files, the FileBrowser is an alternative to an FTP-client. Moreover, you are able to define different image versions according to your websites grid. Alternatives to the FileBrowser can be found at http://djangopackages.com/grids/g/file-managers/.

## Do I need Grappelli?

Grappelli is a requirement for using the FileBrowser. There are several filebrowser-no-grappelli repositories (most of them on GitHub), but we don’t follow the development.

## I need help!

see Troubleshooting.

## Why are there no fancy effects?

The FileBrowser is about managing files. We think that you should prepare your files before uploading them to the server.

## How do I upload to another server?

Use a custom storage engine, see https://docs.djangoproject.com/en/1.11/howto/custom-file-storage/.

## Why do I need image-versions?

You need image-versions if your website is based on a grid.

## Is the FileBrowser stable?

We’ve developed the FileBrowser for a couple of years and use it with almost all of our clients. That said, Grappelli is the more stable and mature application.

## How can I contribute?

Help is very much needed and appreciated. Test the FileBrowser and submit feedback/patches.

## Who develops the FileBrowser?

The FileBrowser is developed and maintained by Patrick Kranzlmüller & Axel Swoboda of vonautomatisch.